HexApplication class

BIP85 application for deriving hexadecimal entropy (application number 128169).

Inheritance

Constructors

HexApplication()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
number int
The application number according to BIP85 specification.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parsePath(String path) → ({int index, int numBytes})
Parses a BIP85 hex derivation path and returns the number of bytes and index.