PasswordBase85Application class

BIP85 application for deriving Base85 encoded passwords (application number 707785).

Inheritance

Constructors

PasswordBase85Application()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
number int
The application number according to BIP85 specification.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parsePath(String path) → ({int index, int pwdLen})
Parses a BIP85 password derivation path and returns the password length and index.