bip85_entropy library
BIP85 deterministic entropy derivation library.
This library provides functionality to derive deterministic entropy from master keys according to BIP85 specification.
Classes
- Bip85Application
- Base class for BIP85 applications. Each application has a unique number that identifies its purpose.
- Bip85Entropy
- Main class for deriving deterministic entropy from BIP32 extended private keys according to the BIP85 specification.
- Bip85HardenedPath
- Represents a BIP85 derivation path where all components must be hardened. A hardened path component ends with a single quote character (').
- CustomApplication
- Custom BIP85 application with a user-defined application number. Use this for non-standard BIP85 applications.
- DiceApplication
- BIP85 application for deriving dice rolls (application number 89101).
- HexApplication
- BIP85 application for deriving hexadecimal entropy (application number 128169).
- Mnemonic
- BIP39: A mnemonic sentence is superior for human interaction compared to the handling of raw binary or hexadecimal representations of a wallet seed.
- MnemonicApplication
- BIP85 application for deriving BIP39 mnemonic phrases (application number 39).
- PasswordBase64Application
- BIP85 application for deriving Base64 encoded passwords (application number 707764).
- PasswordBase85Application
- BIP85 application for deriving Base85 encoded passwords (application number 707785).
- RsaApplication
- BIP85 application for deriving RSA keys (application number 828365).
- WifApplication
- BIP85 application for deriving Wallet Import Format (WIF) keys (application number 2).
- XprvApplication
- BIP85 application for deriving extended private keys (xprv) (application number 32).
Enums
- Language
- BIP39: Since the vast majority of BIP39 wallets supports only the English wordlist, it is strongly discouraged to use non-English wordlists for generating the mnemonic sentences. If you still feel your application really needs to use a localized wordlist, use one of the following instead of inventing your own.
- MnemonicLength
Extensions
- Bip39LanguageExtension on Language
- Extension on bip39.Language to convert between language and BIP85 code.
- Bip39MnemonicLengthExtension on MnemonicLength
- Extension on bip39.MnemonicLength to convert between mnemonic length and BIP85 code.
Exceptions / Errors
- Bip85ApplicationException
- Exception thrown when there is an error with BIP85 application handling.
- Bip85Exception
- Base exception for BIP85 related errors.
- MnemonicException
- MnemonicIndexesLengthException
- MnemonicInvalidChecksumException
- MnemonicUnexpectedEntropyLengthException
- MnemonicUnexpectedPartialSentenceLengthException
- MnemonicUnexpectedSentenceLengthException
- MnemonicWordNotFoundException